@@ -27,7 +27,7 @@ our %EXPORT_TAGS = (
 	'all' => \@EXPORT_OK,
 	);
 
-our $VERSION = '1.503';
+our $VERSION = '1.505';
 
 =encoding utf8
 
@@ -265,7 +265,7 @@ sub parse_plist_file {
 		return;
 		}
 
-	my $text = do { local $/; open my($fh), $file; <$fh> };
+	my $text = do { local $/; open my($fh), '<:raw', $file; <$fh> };
 
 	parse_plist( $text );
 	}
@@ -1019,13 +1019,13 @@ all the plist junk and just play with the data.
 
 =head1 AUTHOR
 
-brian d foy, C<< <bdfoy@cpan.org> >>
+brian d foy, C<< <briandfoy@pobox.com> >>
 
 Tom Wyant added support for UID types.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2004-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2004-2024, brian d foy <briandfoy@pobox.com>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License 2.0.
