@@ -9,11 +9,11 @@ use Data::Dumper;
 use Encode            qw(decode);
 use Mac::PropertyList;
 use Math::BigInt;
-use MIME::Base64      qw(decode_base64);
 use POSIX             qw(SEEK_END SEEK_SET);
-use XML::Entities     ();
 
-our $VERSION = '1.503';
+our $VERSION = '1.505';
+
+my $Debug = $ENV{PLIST_DEBUG} || 0;
 
 __PACKAGE__->_run( @ARGV ) unless caller;
 
@@ -138,6 +138,8 @@ sub _read_plist_trailer {
 	@hash{ qw( offset_size ref_size object_count top_object table_offset ) }
 		= unpack "x6 C C (x4 N)3", $buffer;
 
+	print Dumper( \%hash );
+
 	$self->{trailer} = \%hash;
 	}
 
@@ -165,8 +167,6 @@ sub _get_offset_table {
 sub _read_object_at_offset {
 	my( $self, $offset ) = @_;
 
-	my @caller = caller(1);
-
     seek $self->_fh, ${ $self->_offsets }[$offset], SEEK_SET;
 
     $self->_read_object;
@@ -197,19 +197,19 @@ my $type_readers = {
     	},
 
 	1 => sub { # integers
-		my( $self, $power2 ) = @_;
+		my( $self, $power_of_2 ) = @_;
 
-		croak "Integer with <$power2> bytes is not supported" if $power2 > 3;
+		croak "Integer with <$power_of_2> bytes is not supported" if $power_of_2 > 4;
 
-		my $byte_length = 1 << $power2;
+		my $byte_length = 1 << $power_of_2;
 
 		my( $buffer, $value );
 		read $self->_fh, $buffer, $byte_length;
 
 		my @formats = qw( C n N NN NNNN );
-		my @values = unpack $formats[$power2], $buffer;
+		my @values = unpack $formats[$power_of_2], $buffer;
 
-		if( $power2 == 3 ) {
+		if( $power_of_2 == 3 ) { # 64 bits
 			my( $high, $low ) = @values;
 
 			my $b = Math::BigInt->new($high)->blsft(32)->bior($low);
@@ -219,7 +219,9 @@ my $type_readers = {
 
 			@values = ( $b );
 			}
-		elsif( $power2 == 4 ) {
+		elsif( $power_of_2 == 4 ) { # 128 bits
+		    # 128 bits aren't part of the public API, but apparently
+		    # they are out there.
 			my( $highest, $higher, $high, $low ) = @values;
 			my $b = Math::BigInt
 				->new($highest)
@@ -366,25 +368,21 @@ my $type_readers = {
 
 sub _read_object {
 	my $self = shift;
-say "Reading object!";
     my $buffer;
-    say "\tTELL: ", tell( $self->_fh );
+
     croak "read() failed while trying to get type byte! $!"
     	unless read( $self->_fh, $buffer, 1) == 1;
 
     my $length = unpack( "C*", $buffer ) & 0x0F;
-say "\tlength is $length";
     $buffer    = unpack "H*", $buffer;
-    say "\t", join '', map { sprintf '%02x', ord } split //, $buffer;
     my $type   = substr $buffer, 0, 1;
-say "\ttype is $type";
 
 	$length = $self->_read_object->value if $type ne "0" && $length == 15;
 
 	my $sub = $type_readers->{ $type };
 	my $result = eval { $sub->( $self, $length ) };
 	croak "$@" if $@;
-say "RESULT: ", Dumper($result);
+
     return $result;
 	}
 
@@ -414,7 +412,7 @@ Tom Wyant added support for UID types.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2004-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2004-2024, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License 2.0.
